@@ -18,20 +18,30 @@ def csv2json(origen, destino, files_json):
     files = []
     files_json_path = Path(files_json)
     if not files_json_path.exists():
-        fields = ["model", "file", "field", "opts"]
+        fields = ["models", "file", "field", "opts"]
         files = [
             dict(zip(fields,
-                     ('station.station', 'station.csv', 'name', {}))),
+                     ({
+                         'station.station':{"name","code","ecef_x","ecef_y","ecef_z"},
+                         "station.inetdata":{"name","interface_host","interface_port",
+                                             "protocol_host", "protocol_port", "protocol",
+                                             "network_id"}
+                     }, 'station.csv', 'name',
+                      {"port":int, "interface_port":int, "active":bool}))),
             dict(zip(fields,
-                     ('database.dbdata', 'dbdata_info.csv',
-                      'name', {"port": int, "dbtype": add_list}))),
+                     ({'database.dbdata':{"name","path","host","port","user","passw", "info", "dbtype"}},
+                      'dbdata_info.csv',
+                      'name', {"port": int}))),
             dict(zip(fields,
-                     ("network_register.network_register", "network.csv",
+                     ({'database.dbtype':{"typedb","name","url","data_list"}},
+                      'dbtype.csv',
+                      'name', {}))),
+            dict(zip(fields,
+                     ({"network_register.network_register":{"name","url","description"}}, "network.csv",
                       "name", {}))),
-            dict(zip(fields,("server.server", "server.csv",
-                             "host_name", {}))),
-            dict(zip(fields,('database.dbtype', 'dbtype.csv',
-                             'name', {})))
+            dict(zip(fields,({"server.server":{"host_name","host_ip","gnsocket_port","activated"}},
+                             "server.csv",
+                             "host_name", {"gnsocket_port":int, "activated":bool}))),
         ]
     else:
         print("Leyendo de ./files.json")
